from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CcidCls:
	"""Ccid commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ccid", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:CDATa:CCID:STATe \n
		Snippet: value: bool = driver.source.bb.btooth.cs.cdata.ccid.get_state() \n
		Enables the CS configuration ID. Set this ID with the following command: [:SOURce<hw>]:BB:BTOoth:CS:CDATa:CID \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:CS:CDATa:CCID:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:CDATa:CCID:STATe \n
		Snippet: driver.source.bb.btooth.cs.cdata.ccid.set_state(state = False) \n
		Enables the CS configuration ID. Set this ID with the following command: [:SOURce<hw>]:BB:BTOoth:CS:CDATa:CID \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:CS:CDATa:CCID:STATe {param}')
