from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TpmCls:
	"""Tpm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tpm", core, parent)

	def set(self, tpm: enums.BtoCsTpm, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:[SEVent<CH0>]:MTHRee:TPM \n
		Snippet: driver.source.bb.btooth.cs.sevent.mthree.tpm.set(tpm = enums.BtoCsTpm.TPM_10, channelNull = repcap.ChannelNull.Default) \n
		Sets the time 'T_PM' for Mode-2 or Mode-3 CS steps. \n
			:param tpm: TPM_10| TPM_20| TPM_40| TPM_652 TPM_x, x represents values in microseconds.
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sevent')
		"""
		param = Conversions.enum_scalar_to_str(tpm, enums.BtoCsTpm)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:CS:SEVent{channelNull_cmd_val}:MTHRee:TPM {param}')

	# noinspection PyTypeChecker
	def get(self, channelNull=repcap.ChannelNull.Default) -> enums.BtoCsTpm:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:[SEVent<CH0>]:MTHRee:TPM \n
		Snippet: value: enums.BtoCsTpm = driver.source.bb.btooth.cs.sevent.mthree.tpm.get(channelNull = repcap.ChannelNull.Default) \n
		Sets the time 'T_PM' for Mode-2 or Mode-3 CS steps. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sevent')
			:return: tpm: No help available"""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:CS:SEVent{channelNull_cmd_val}:MTHRee:TPM?')
		return Conversions.str_to_scalar_enum(response, enums.BtoCsTpm)
