from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StypeCls:
	"""Stype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stype", core, parent)

	def set(self, seq_type: enums.BtoCsSequenceType, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:[SEVent<CH0>]:STYPe \n
		Snippet: driver.source.bb.btooth.cs.sevent.stype.set(seq_type = enums.BtoCsSequenceType.RANDom, channelNull = repcap.ChannelNull.Default) \n
		Sets the sequence type. \n
			:param seq_type: SOUNding| RANDom SOUNding Sounding sequence RANDom Random sequence
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sevent')
		"""
		param = Conversions.enum_scalar_to_str(seq_type, enums.BtoCsSequenceType)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:CS:SEVent{channelNull_cmd_val}:STYPe {param}')

	# noinspection PyTypeChecker
	def get(self, channelNull=repcap.ChannelNull.Default) -> enums.BtoCsSequenceType:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:[SEVent<CH0>]:STYPe \n
		Snippet: value: enums.BtoCsSequenceType = driver.source.bb.btooth.cs.sevent.stype.get(channelNull = repcap.ChannelNull.Default) \n
		Sets the sequence type. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sevent')
			:return: seq_type: SOUNding| RANDom SOUNding Sounding sequence RANDom Random sequence"""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:CS:SEVent{channelNull_cmd_val}:STYPe?')
		return Conversions.str_to_scalar_enum(response, enums.BtoCsSequenceType)
