from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpayloadCls:
	"""Upayload commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("upayload", core, parent)

	def set(self, user_payload: str, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:[SEVent<CH0>]:UPAYload \n
		Snippet: driver.source.bb.btooth.cs.sevent.upayload.set(user_payload = 'abc', channelNull = repcap.ChannelNull.Default) \n
		Selects a data list file as the data source for a random CS sequence. This sequence uses the CS_SYNC_User_Payload for CS
		step configuration modes Mode-1 or Mode-3. Select the file from the default instrument directory or a specific directory. \n
			:param user_payload: string
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sevent')
		"""
		param = Conversions.value_to_quoted_str(user_payload)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:CS:SEVent{channelNull_cmd_val}:UPAYload {param}')

	def get(self, channelNull=repcap.ChannelNull.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:[SEVent<CH0>]:UPAYload \n
		Snippet: value: str = driver.source.bb.btooth.cs.sevent.upayload.get(channelNull = repcap.ChannelNull.Default) \n
		Selects a data list file as the data source for a random CS sequence. This sequence uses the CS_SYNC_User_Payload for CS
		step configuration modes Mode-1 or Mode-3. Select the file from the default instrument directory or a specific directory. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sevent')
			:return: user_payload: string"""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:CS:SEVent{channelNull_cmd_val}:UPAYload?')
		return trim_str_response(response)
