from ...............Internal.Core import Core
from ...............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FsCls:
	"""Fs commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fs", core, parent)

	@property
	def fsFactor(self):
		"""fsFactor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fsFactor'):
			from .FsFactor import FsFactorCls
			self._fsFactor = FsFactorCls(self._core, self._cmd_group)
		return self._fsFactor

	@property
	def srIdx(self):
		"""srIdx commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srIdx'):
			from .SrIdx import SrIdxCls
			self._srIdx = SrIdxCls(self._core, self._cmd_group)
		return self._srIdx

	def clone(self) -> 'FsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
