from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NonOfdmaUserCls:
	"""NonOfdmaUser commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nonOfdmaUser", core, parent)

	def set(self, non_ofdma_user: int, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:NONOfdmaUser \n
		Snippet: driver.source.bb.wlnn.fblock.nonOfdmaUser.set(non_ofdma_user = 1, frameBlock = repcap.FrameBlock.Default) \n
		Sets the number of non-OFDMA users. \n
			:param non_ofdma_user: integer Range: 1 to 8
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.decimal_value_to_str(non_ofdma_user)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:NONOfdmaUser {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:NONOfdmaUser \n
		Snippet: value: int = driver.source.bb.wlnn.fblock.nonOfdmaUser.get(frameBlock = repcap.FrameBlock.Default) \n
		Sets the number of non-OFDMA users. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: non_ofdma_user: integer Range: 1 to 8"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:NONOfdmaUser?')
		return Conversions.str_to_int(response)
