from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GainCls:
	"""Gain commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gain", core, parent)

	def set(self, gain: float, mimoTap=repcap.MimoTap.Default) -> None:
		"""SCPI: [SOURce<HW>]:CEMulation:MIMO:TAP<CH>:GVECtor:AA:GAIN \n
		Snippet: driver.source.cemulation.mimo.tap.gvector.aa.gain.set(gain = 1.0, mimoTap = repcap.MimoTap.Default) \n
		No command help available \n
			:param gain: No help available
			:param mimoTap: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tap')
		"""
		param = Conversions.decimal_value_to_str(gain)
		mimoTap_cmd_val = self._cmd_group.get_repcap_cmd_value(mimoTap, repcap.MimoTap)
		self._core.io.write(f'SOURce<HwInstance>:CEMulation:MIMO:TAP{mimoTap_cmd_val}:GVECtor:AA:GAIN {param}')

	def get(self, mimoTap=repcap.MimoTap.Default) -> float:
		"""SCPI: [SOURce<HW>]:CEMulation:MIMO:TAP<CH>:GVECtor:AA:GAIN \n
		Snippet: value: float = driver.source.cemulation.mimo.tap.gvector.aa.gain.get(mimoTap = repcap.MimoTap.Default) \n
		No command help available \n
			:param mimoTap: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tap')
			:return: gain: No help available"""
		mimoTap_cmd_val = self._cmd_group.get_repcap_cmd_value(mimoTap, repcap.MimoTap)
		response = self._core.io.query_str(f'SOURce<HwInstance>:CEMulation:MIMO:TAP{mimoTap_cmd_val}:GVECtor:AA:GAIN?')
		return Conversions.str_to_float(response)
